@@ -294,6 +294,7 @@ from .._impl import (
     scout_compute_api_RollingOperationSeries as RollingOperationSeries,
     scout_compute_api_RollingOperator as RollingOperator,
     scout_compute_api_RollingOperatorVisitor as RollingOperatorVisitor,
+    scout_compute_api_RootMeanSquare as RootMeanSquare,
     scout_compute_api_RunChannel as RunChannel,
     scout_compute_api_ScaleSeries as ScaleSeries,
     scout_compute_api_Scatter as Scatter,
@@ -329,6 +330,8 @@ from .._impl import (
     scout_compute_api_StringConstantVisitor as StringConstantVisitor,
     scout_compute_api_StringSetConstant as StringSetConstant,
     scout_compute_api_StringSetConstantVisitor as StringSetConstantVisitor,
+    scout_compute_api_StructSeries as StructSeries,
+    scout_compute_api_StructSeriesVisitor as StructSeriesVisitor,
     scout_compute_api_Sum as Sum,
     scout_compute_api_SumSeries as SumSeries,
     scout_compute_api_SummarizationStrategy as SummarizationStrategy,
@@ -675,6 +678,7 @@ __all__ = [
     'RollingOperationSeries',
     'RollingOperator',
     'RollingOperatorVisitor',
+    'RootMeanSquare',
     'RunChannel',
     'ScaleSeries',
     'Scatter',
@@ -710,6 +714,8 @@ __all__ = [
     'StringConstantVisitor',
     'StringSetConstant',
     'StringSetConstantVisitor',
+    'StructSeries',
+    'StructSeriesVisitor',
     'Sum',
     'SumSeries',
     'SummarizationStrategy',
