@@ -142,6 +142,8 @@ from .._impl import (
     scout_compute_resolved_api_StaleRangesNode as StaleRangesNode,
     scout_compute_resolved_api_StorageLocator as StorageLocator,
     scout_compute_resolved_api_StorageLocatorVisitor as StorageLocatorVisitor,
+    scout_compute_resolved_api_StructSeriesNode as StructSeriesNode,
+    scout_compute_resolved_api_StructSeriesNodeVisitor as StructSeriesNodeVisitor,
     scout_compute_resolved_api_SumSeriesNode as SumSeriesNode,
     scout_compute_resolved_api_SummarizeCartesian3dNode as SummarizeCartesian3dNode,
     scout_compute_resolved_api_SummarizeCartesianNode as SummarizeCartesianNode,
@@ -309,6 +311,8 @@ __all__ = [
     'StaleRangesNode',
     'StorageLocator',
     'StorageLocatorVisitor',
+    'StructSeriesNode',
+    'StructSeriesNodeVisitor',
     'SumSeriesNode',
     'SummarizeCartesian3dNode',
     'SummarizeCartesianNode',
