@@ -12,6 +12,7 @@ from .._impl import (
     scout_dataexport_api_ExportFormatVisitor as ExportFormatVisitor,
     scout_dataexport_api_ExportTimeDomainChannels as ExportTimeDomainChannels,
     scout_dataexport_api_Iso8601TimestampFormat as Iso8601TimestampFormat,
+    scout_dataexport_api_Matfile as Matfile,
     scout_dataexport_api_MergeTimestampStrategy as MergeTimestampStrategy,
     scout_dataexport_api_MergeTimestampStrategyVisitor as MergeTimestampStrategyVisitor,
     scout_dataexport_api_NoneStrategy as NoneStrategy,
@@ -36,6 +37,7 @@ __all__ = [
     'ExportFormatVisitor',
     'ExportTimeDomainChannels',
     'Iso8601TimestampFormat',
+    'Matfile',
     'MergeTimestampStrategy',
     'MergeTimestampStrategyVisitor',
     'NoneStrategy',
