@@ -5,6 +5,7 @@ from .._impl import (
     scout_metadata_ListPropertiesAndLabelsResponse as ListPropertiesAndLabelsResponse,
     scout_metadata_ResourceMetadataService as ResourceMetadataService,
     scout_metadata_ResourceType as ResourceType,
+    scout_metadata_StringArrayLengthQuery as StringArrayLengthQuery,
 )
 
 __all__ = [
@@ -12,6 +13,7 @@ __all__ = [
     'ListPropertiesAndLabelsRequest',
     'ListPropertiesAndLabelsResponse',
     'ResourceType',
+    'StringArrayLengthQuery',
     'ResourceMetadataService',
 ]
 
