@@ -22,12 +22,10 @@ from .._impl import (
     scout_run_api_GetRunByIdRequest as GetRunByIdRequest,
     scout_run_api_GetRunsByAssetRequest as GetRunsByAssetRequest,
     scout_run_api_GetRunsByAssetResponse as GetRunsByAssetResponse,
-    scout_run_api_LabelsFilter as LabelsFilter,
     scout_run_api_Link as Link,
     scout_run_api_LogSetRid as LogSetRid,
     scout_run_api_PresetTimeframeDuration as PresetTimeframeDuration,
     scout_run_api_PresetTimeframeFilter as PresetTimeframeFilter,
-    scout_run_api_PropertiesFilter as PropertiesFilter,
     scout_run_api_RefNameAndType as RefNameAndType,
     scout_run_api_Run as Run,
     scout_run_api_RunDataReviewEvaluationStatus as RunDataReviewEvaluationStatus,
@@ -83,12 +81,10 @@ __all__ = [
     'GetRunByIdRequest',
     'GetRunsByAssetRequest',
     'GetRunsByAssetResponse',
-    'LabelsFilter',
     'Link',
     'LogSetRid',
     'PresetTimeframeDuration',
     'PresetTimeframeFilter',
-    'PropertiesFilter',
     'RefNameAndType',
     'Run',
     'RunDataReviewEvaluationStatus',
