@@ -8,6 +8,7 @@ from .._impl import (
     themes_api_ChartTypeThemes as ChartTypeThemes,
     themes_api_CreateChartThemeRequest as CreateChartThemeRequest,
     themes_api_HexColor as HexColor,
+    themes_api_LegendPlacement as LegendPlacement,
     themes_api_LegendPosition as LegendPosition,
     themes_api_TextAlignment as TextAlignment,
     themes_api_TextDirection as TextDirection,
@@ -27,6 +28,7 @@ __all__ = [
     'ChartTypeThemes',
     'CreateChartThemeRequest',
     'HexColor',
+    'LegendPlacement',
     'LegendPosition',
     'TextAlignment',
     'TextDirection',
