@@ -17,8 +17,6 @@ from .._impl import (
     timeseries_logicalseries_api_ContextProperty as ContextProperty,
     timeseries_logicalseries_api_ContextPropertyVisitor as ContextPropertyVisitor,
     timeseries_logicalseries_api_CreateLogicalSeries as CreateLogicalSeries,
-    timeseries_logicalseries_api_CsvLocator as CsvLocator,
-    timeseries_logicalseries_api_CsvLocatorV2 as CsvLocatorV2,
     timeseries_logicalseries_api_DatabaseName as DatabaseName,
     timeseries_logicalseries_api_DatasetName as DatasetName,
     timeseries_logicalseries_api_FieldName as FieldName,
@@ -69,8 +67,6 @@ __all__ = [
     'ContextProperty',
     'ContextPropertyVisitor',
     'CreateLogicalSeries',
-    'CsvLocator',
-    'CsvLocatorV2',
     'DatabaseName',
     'DatasetName',
     'FieldName',
