@@ -1,16 +1,12 @@
 # coding=utf-8
 from .._impl import (
-    timeseries_seriescache_api_CachedSeries as CachedSeries,
-    timeseries_seriescache_api_CachedSeriesResponse as CachedSeriesResponse,
     timeseries_seriescache_api_Chunk as Chunk,
     timeseries_seriescache_api_ChunkType as ChunkType,
-    timeseries_seriescache_api_CreateCachedSeriesRequest as CreateCachedSeriesRequest,
     timeseries_seriescache_api_CreateChunk as CreateChunk,
     timeseries_seriescache_api_CreateChunksParameters as CreateChunksParameters,
     timeseries_seriescache_api_CreateChunksResponse as CreateChunksResponse,
     timeseries_seriescache_api_DeleteChunksParameters as DeleteChunksParameters,
     timeseries_seriescache_api_DeleteChunksResponse as DeleteChunksResponse,
-    timeseries_seriescache_api_GetCachedSeriesRequest as GetCachedSeriesRequest,
     timeseries_seriescache_api_GetChunksParameters as GetChunksParameters,
     timeseries_seriescache_api_GetChunksResponse as GetChunksResponse,
     timeseries_seriescache_api_Handle as Handle,
@@ -20,17 +16,13 @@ from .._impl import (
 )
 
 __all__ = [
-    'CachedSeries',
-    'CachedSeriesResponse',
     'Chunk',
     'ChunkType',
-    'CreateCachedSeriesRequest',
     'CreateChunk',
     'CreateChunksParameters',
     'CreateChunksResponse',
     'DeleteChunksParameters',
     'DeleteChunksResponse',
-    'GetCachedSeriesRequest',
     'GetChunksParameters',
     'GetChunksResponse',
     'Handle',
