@@ -3,3 +3,7 @@ from .._impl import (
     upload_api_UploadService as UploadService,
 )
 
+__all__ = [
+    'UploadService',
+]
+
